CoderConfig class

CoderConfig provides global reactive states for common app-level settings.

This class holds static instances of CoderState that can be accessed anywhere in the app to reactively manage things like theme and locale.

Example:

CoderConfig.themeMode.value = ThemeMode.dark;
CoderConfig.locale.value = Locale('en');

Constructors

CoderConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

locale → CoderState<Locale?>
Global reactive state for Locale. Can be used to change app language:
final
themeMode → CoderState<ThemeMode>
Global reactive state for ThemeMode (light, dark, or system). Can be used with MaterialApp's themeMode:
final